==> openapi-facade-0.0.1-20200707.090108-28-sources.jar: com/bizvane/openapifacade/rpc/CommonFeignRpc.java <==
package com.bizvane.openapifacade.rpc;

import com.bizvane.openapifacade.models.vo.CommonOrderRequestApiVo;
import com.bizvane.openapifacade.models.vo.IntegralAdjustYmRequestVO;
import com.bizvane.openapifacade.yanzhiwu.vo.CommonOpenCardRequestVo;
import com.bizvane.openapifacade.yanzhiwu.vo.CommonOpenCardResponseVo;
import com.bizvane.openapifacade.yanzhiwu.vo.YMStaffSyncRequestVo;
import com.bizvane.openapifacade.yanzhiwu.vo.YMStoreSyncRequestVo;
import com.bizvane.utils.responseinfo.ResponseData;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;

import javax.validation.Valid;

/**
 * 内部调用会员标准开卡rpc接口
 *
 * @author <a href="mailto:im.leexiao@gamil.com">KitAndrew</a>
 * @since 2020年07月02日 17:14:00
 */
@FeignClient(value = "${feign.client.openapi.name}",path = "${feign.client.openapi.path}/common")
public interface CommonFeignRpc {


    @PostMapping(value = "/member/openCard")
    ResponseData<CommonOpenCardResponseVo> openCard(@RequestBody @Valid CommonOpenCardRequestVo requestVo);

    @PostMapping(value = "/order/addCommonOrder")
    ResponseData<String> addCommonOrder(@RequestBody @Valid CommonOrderRequestApiVo requestApiVo);

    @PostMapping(value = "/staff/syncStaff")
    ResponseData addStaffInfo(@RequestBody @Valid YMStaffSyncRequestVo requestVo);

    @PostMapping(value = "/store/syncStore")
    ResponseData addAndUpdateStoreInfo(@RequestBody @Valid YMStoreSyncRequestVo requestVo);

    @PostMapping(value = "/integral/integralAdjust")
    ResponseData integralAdjust(@RequestBody @Valid IntegralAdjustYmRequestVO vo);
}

==> openapi-facade-0.0.2-20210809.045341-4-sources.jar: com/bizvane/openapifacade/rpc/CommonFeignRpc.java <==
package com.bizvane.openapifacade.rpc;

import com.bizvane.couponfacade.models.vo.standard.StandardCouponUseRequestVo;
import com.bizvane.openapifacade.models.vo.CommonOrderRequestApiVo;
import com.bizvane.openapifacade.models.vo.IntegralAdjustYmRequestVO;
import com.bizvane.openapifacade.yanzhiwu.vo.CommonOpenCardRequestVo;
import com.bizvane.openapifacade.yanzhiwu.vo.CommonOpenCardResponseVo;
import com.bizvane.openapifacade.yanzhiwu.vo.YMStaffSyncRequestVo;
import com.bizvane.openapifacade.yanzhiwu.vo.YMStoreSyncRequestVo;
import com.bizvane.utils.responseinfo.ResponseData;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;

import javax.validation.Valid;

/**
 * 内部调用会员标准开卡rpc接口
 *
 * @author <a href="mailto:im.leexiao@gamil.com">KitAndrew</a>
 * @since 2020年07月02日 17:14:00
 */
@FeignClient(value = "${feign.client.openapi.name}",path = "${feign.client.openapi.path}/common")
public interface CommonFeignRpc {


    @PostMapping(value = "/member/openCard")
    ResponseData<CommonOpenCardResponseVo> openCard(@RequestBody @Valid CommonOpenCardRequestVo requestVo);

    @PostMapping(value = "/order/addCommonOrder")
    ResponseData<String> addCommonOrder(@RequestBody @Valid CommonOrderRequestApiVo requestApiVo);

    @PostMapping(value = "/staff/syncStaff")
    ResponseData addStaffInfo(@RequestBody @Valid YMStaffSyncRequestVo requestVo);

    @PostMapping(value = "/store/syncStore")
    ResponseData addAndUpdateStoreInfo(@RequestBody @Valid YMStoreSyncRequestVo requestVo);

    @PostMapping(value = "/integral/integralAdjust")
    ResponseData integralAdjust(@RequestBody @Valid IntegralAdjustYmRequestVO vo);

    /**
     * 券核销接口
     * @param requestVo
     * @return
     */
    @PostMapping(value = "/coupon/couponUse")
    ResponseData<String> couponUse(@RequestBody StandardCouponUseRequestVo requestVo);
}
